Learn R Programming

NegBinBetaBinreg (version 1.0)

NegBinBetaBinreg-package: NegBinBetaBinreg

Description

Function to estimate a Negative Binomial regression models with mean and shape (or variance) regression structures, and Beta Binomial regression with mean and dispersion regression structures.

Arguments

Details

Package:
NegBinBetaBinreg
Type:
Package
Version:
1.0
Date:
2016-10-8
License:
GPL-2
LazyLoad:
yes