Usage
gammakernel(y, x, z,betas.ini,gammas.now,gammas.old,gpri,Gpri,model,m,ni)
Arguments
y
object of class matrix, with the dependent variable
x
object of class matrix, with the variables for modelling the mean
z
object of class matrix, with the variables for modelling the variance
betas.ini
a vector with the beta that define the old p.d.f
gammas.now
a vector with the gamma parameter - new parameters - to evaluate in the old p.d.f
gammas.old
a vector with the gamma that define the old p.d.f
gpri
a vector with the initial values of gamma
Gpri
a matrix with the initial values of the variance of gamma
model
it indicates the model that will be used. By default, is the Beta Binomial model (BB), but it could also be the Negative Binomial with mean and shape (NB1) or the Negative Binomial with mean and variance (NB2).
m
It is positive integer that In the Beta Binomial model indicates the number of trials. By default, is the number of data
ni
It is a vector of positive integer that In the Beta Binomial model indicates the number of trials to each individual. By default, is a vector of m