Learn R Programming

NegBinBetaBinreg (version 1.0)

print.summary.NegBinBetaBinreg: print the summary of the NegBinBetaBinreg

Description

Print the summary for a Negative Binomial regression models with mean and shape (or variance) regression structures, and Beta Binomial regression with mean and dispersion regression structures.

Usage

"print"(x, ...)

Arguments

x
object of class NegBinBetaBinreg
...
not used.

Value

Print the summary for a Negative Binomial regression with mean and shape modeling and mean and variance modeling and Beta Binomial regression with mean and dispersion modeling

References

1. Cepeda C. E. (2001). Modelagem da variabilidade em modelos lineares generalizados. Unpublished Ph.D. tesis. Instituto de Matematicas. Universidade Federal do Rio do Janeiro. //http://www.docentes.unal.edu.co/ecepedac/docs/MODELAGEM20DA20VARIABILIDADE.pdf. http://www.bdigital.unal.edu.co/9394/. 2.Cepeda, E. C. and Gamerman D. (2005). Bayesian Methodology for modeling parameters in the two-parameter exponential family. Estadistica 57, 93 105. // 3.Cepeda, E. and Garrido, L. (2011). Bayesian beta regression models: joint mean and precision modeling. Universidad Nacional // 4.Cepeda, E. and Migon, H. and Garrido, L. and Achcar, J. (2012) Generalized Linear models with random effects in the two parameter exponential family. Journal of Statistical Computation and Simulation. 1, 1 13. // 5.Cepeda-Cuervo, E. and Cifuentes-Amado, V. (2016) Double generalized beta-binomial and negative binomial regression. To appear.