Usage
dpostg(y,x,z,betas,gammas,gpri,Gpri,model,m)
Arguments
y
object of class matrix, with the dependent variable
x
object of class matrix, with the variables for modelling the mean
z
object of class matrix, with the variables for modelling the variance
betas
a vector with the previous proposal beta parameters
gammas
a vector with the previous proposal gamma parameters
gpri
a vector with the initial values of gamma
Gpri
a matrix with the initial values of the variance of gamma
model
it indicates the model that will be used. By default, is the Beta Binomial model (BB), but it could also be the Negative Binomial with mean and shape (NB1) or the Negative Binomial with mean and variance (NB2).
m
It is positive integer that In the Beta Binomial model indicates the number of trials. By default, is the number of data